Module browser

Module browser 

Browser — Bonjour and application-service discovery via nw_browser.

Structs

BonjourAdvertiser
RAII guard for a running Bonjour service advertisement. Drop to stop publishing the service to the local network.
BrowseDescriptor
A descriptor describing what a browser should look for.
BrowseResult
Rich browse result metadata delivered by nw_browser.
BrowseResultChange
Bitflags describing how a browse result changed.
BrowseResultsBrowser
RAII guard for a running nw_browser that delivers rich browse-result objects.
Browser
RAII guard for a running nw_browser. Drop to stop receiving discovery callbacks.
DiscoveredService
One Bonjour service that the browser has observed appearing or disappearing on the network.

Enums

BrowserEvent
Discovery event delivered to the browser closure.
BrowserState
Browser lifecycle states reported by nw_browser_set_state_changed_handler.

Functions

advertise_bonjour_service
Publish a Bonjour service on the local network.
start_browser
Start browsing for Bonjour services of service_type in domain.
start_browser_results_with_descriptor
Start browsing with rich browse-result objects and change metadata.
start_browser_with_descriptor
Start browsing with an explicit descriptor and optional parameters.