pub struct BrowseDescriptor { /* private fields */ }Expand description
A descriptor describing what a browser should look for.
Implementations
Sourceimpl BrowseDescriptor
impl BrowseDescriptor
Sourcepub fn bonjour_service(
service_type: &str,
domain: Option<&str>,
) -> Result<Self, NetworkError>
pub fn bonjour_service( service_type: &str, domain: Option<&str>, ) -> Result<Self, NetworkError>
Create a Bonjour browse descriptor.
Sourcepub fn application_service(name: &str) -> Result<Self, NetworkError>
pub fn application_service(name: &str) -> Result<Self, NetworkError>
Create an application-service browse descriptor.
Sourcepub fn bonjour_service_type(&self) -> Option<String>
pub fn bonjour_service_type(&self) -> Option<String>
Bonjour service type, if this is a Bonjour browse descriptor.
Sourcepub fn bonjour_service_domain(&self) -> Option<String>
pub fn bonjour_service_domain(&self) -> Option<String>
Bonjour service domain, if explicitly configured.
Sourcepub fn set_include_txt_record(&mut self, include_txt_record: bool) -> &mut Self
pub fn set_include_txt_record(&mut self, include_txt_record: bool) -> &mut Self
Enable or disable TXT-record inclusion during browsing.
Sourcepub fn include_txt_record(&self) -> bool
pub fn include_txt_record(&self) -> bool
Whether TXT-record inclusion is enabled.
Sourcepub fn application_service_name(&self) -> Option<String>
pub fn application_service_name(&self) -> Option<String>
Application-service name, if this is an application-service descriptor.